@@ -16,10 +16,11 @@ without a database) are collected.
 from __future__ import annotations
 
 import io
-from typing import IO, Any, Generator, Iterable, NamedTuple, TypeVar
-try:
-    from typing import TypeAlias  #type:ignore
-except ImportError:
+from typing import IO, Any, Generator, Iterable, NamedTuple, TypeVar, Union, Tuple, List
+import sys
+if sys.version_info >= (3, 10):
+    from typing import TypeAlias
+else:
     from typing_extensions import TypeAlias
 import numpy as np
 from collections.abc import Sequence
@@ -47,9 +48,9 @@ def open_general(filename_or_handle: FileLike, iomode: str | None = None) -> IO[
     if reopen_file:
         if iomode is None:
             iomode = 'r'
-        f = open(filename_or_handle, iomode, encoding='utf8')
+        f = open(filename_or_handle, iomode, encoding='utf8')  #type:ignore[arg-type]
     else:
-        f = filename_or_handle
+        f = filename_or_handle  #type:ignore[assignment]
         if f.closed:  # reopen file if it was closed before
             if iomode is None:
                 f = open(f.name, f.mode, encoding='utf8')
@@ -107,7 +108,8 @@ def search_string(searchkey: str, txt: Iterable[str]) -> int:
     return -1
 
 
-def angles_to_vec(magnitude: list | np.ndarray, theta: list | np.ndarray, phi: list | np.ndarray) -> np.ndarray:
+def angles_to_vec(magnitude: list | np.ndarray | float, theta: list | np.ndarray | float,
+                  phi: list | np.ndarray | float) -> np.ndarray:
     """
     convert (magnitude, theta, phi) to (x,y,z)
 
@@ -446,9 +448,9 @@ def is_sequence(arg: Any) -> bool:
     return isinstance(arg, Sequence) and not isinstance(arg, str)
 
 
-_TVectorType = TypeVar('_TVectorType', 'tuple[float, float, float]', 'list[float]', np.ndarray)
+VectorType: TypeAlias = Union[Tuple[float, float, float], List[float], np.ndarray]
+_TVectorType = TypeVar('_TVectorType', bound=VectorType)
 """Generic type variable for atom position types"""
-VectorType: TypeAlias = 'tuple[float, float, float] | list[float] |  np.ndarray'
 
 
 def abs_to_rel(vector: _TVectorType, cell: list[list[float]] | np.ndarray) -> _TVectorType:
@@ -476,7 +478,7 @@ def abs_to_rel(vector: _TVectorType, cell: list[list[float]] | np.ndarray) -> _T
         return relative_vector.tolist()
     if isinstance(vector, tuple):
         return tuple(relative_vector)  #type:ignore
-    return relative_vector
+    return relative_vector  #type:ignore[return-value]
 
 
 def abs_to_rel_f(vector: _TVectorType, cell: list[list[float]] | np.ndarray, pbc: tuple[bool, bool,
@@ -514,7 +516,7 @@ def abs_to_rel_f(vector: _TVectorType, cell: list[list[float]] | np.ndarray, pbc
         return relative_vector.tolist()
     if isinstance(vector, tuple):
         return tuple(relative_vector)  #type:ignore
-    return relative_vector
+    return relative_vector  #type:ignore[return-value]
 
 
 def rel_to_abs(vector: _TVectorType, cell: list[list[float]] | np.ndarray) -> _TVectorType:
@@ -572,7 +574,7 @@ def rel_to_abs_f(vector: _TVectorType, cell: list[list[float]] | np.ndarray) ->
         return absolute_vector.tolist()
     if isinstance(vector, tuple):
         return tuple(absolute_vector)  #type:ignore
-    return absolute_vector
+    return absolute_vector  #type:ignore[return-value]
 
 
 def find_symmetry_relation(from_pos: VectorType,
@@ -636,24 +638,29 @@ class AtomSiteProperties(NamedTuple):
     kind: str
 
 
-def get_wigner_matrix(l: int, phi: float, theta: float) -> np.ndarray:
+def get_wigner_matrix(l: int, alpha: float, beta: float, gamma: float = 0.0, inverse: bool = False) -> np.ndarray:
     """Produces the wigner rotation matrix for the density matrix
 
     :param l: int, orbital quantum number
-    :param phi: float, angle (radian) corresponds to euler angle alpha
-    :param theta: float, angle (radian) corresponds to euler angle beta
+    :param alpha: float, angle (radian) corresponds to euler angle alpha
+    :param beta: float, angle (radian) corresponds to euler angle beta
+    :param gamma: float, angle (radian) corresponds to euler angle gamma
     """
+    if inverse:
+        alpha, beta, gamma = -gamma, -beta, -alpha
+
     d_wigner = np.zeros((7, 7), dtype=complex)
     for m in range(-l, l + 1):
         for mp in range(-l, l + 1):
             base = np.sqrt(fac(l + m) * fac(l - m) * fac(l + mp) * fac(l - mp))
-            base *= np.exp(-1j * phi * mp)
+            base *= np.exp(-1j * alpha * mp) * np.exp(-1j * gamma * m)
 
             for x in range(max(0, m - mp), min(l - mp, l + m) + 1):
                 denom = fac(l - mp - x) * fac(l + m - x) * fac(x) * fac(x + mp - m)
 
-                d_wigner[m + 3, mp + 3] += base/denom * (-1)**x * np.cos(theta/2.0)**(2*l+m-mp-2*x) \
-                                          * np.sin(theta/2.0)**(2*x+mp-m)
+                d_wigner[mp + 3, m + 3] += base/denom * (-1)**x * np.cos(beta/2.0)**(2*l+m-mp-2*x) \
+                                          * np.sin(beta/2.0)**(2*x+mp-m)
+            d_wigner[mp + 3, m + 3] *= (-1)**(m - mp)
 
     return d_wigner
 
