@@ -145,11 +145,12 @@ def _cache_xpath_eval(func: Callable) -> Callable:
     Decorator for the `_xpath_eval` function to speed up concrete xpath calls on the schema
     by caching the results
     """
-    results: dict[str, dict[int, etree._XPathObject]] = {}
+    results: dict[str, dict[int, Any]] = {}
 
+    #in the lxml-stubs xpath evaluation returns etree._XPathObject but as a return type it is next to useless
+    #so we explicitly return Any
     @wraps(func)
-    def wrapper(xmlschema_evaluator: etree.XPathDocumentEvaluator, xpath: str,
-                **variables: etree._XPathObject) -> etree._XPathObject:
+    def wrapper(xmlschema_evaluator: etree.XPathDocumentEvaluator, xpath: str, **variables: etree._XPathObject) -> Any:
         """
         This function produces a hash from all the arguments modifying the behaviour of the wrapped function
         and looks up results in dict based on this hash. If the version of the schema
