@@ -151,6 +151,9 @@ def convert_from_xml_explicit(
     if not isinstance(xmlstring, list):
         xmlstring = [xmlstring]
 
+    if logger is not None:
+        logger.debug('Value to convert from XML: %s', xmlstring)
+
     converted_list: list[ConvertedType | list[ConvertedType]] = []
     all_success = True
     for text in xmlstring:
@@ -184,6 +187,9 @@ def convert_from_xml_explicit(
             if text_definitions[0].length == 1:
                 split_text = [text]
 
+        if logger is not None:
+            logger.debug('Convert from XML: %s using definitions %s', split_text, types)
+
         converted_text, suc = convert_from_xml_single_values(split_text, types, constants=constants, logger=logger)
 
         all_success = all_success and suc
@@ -199,6 +205,9 @@ def convert_from_xml_explicit(
     if len(converted_list) == 1 and not list_return:
         ret_value = converted_list[0]  #type:ignore[assignment]
 
+    if logger is not None:
+        logger.debug('Converted Value from XML: %s', ret_value)
+
     return ret_value, all_success
 
 
@@ -229,6 +238,9 @@ def convert_to_xml_explicit(value: Any | Iterable[Any],
     elif not isinstance(value[0], (list, np.ndarray)) and lengths != {1}:
         value = [value]
 
+    if logger is not None:
+        logger.debug('Value to convert to XML: %s', value)
+
     converted_list = []
     all_success = True
     for val in value:
@@ -261,6 +273,9 @@ def convert_to_xml_explicit(value: Any | Iterable[Any],
 
         types = tuple(definition.base_type for definition in text_definitions)
 
+        if logger is not None:
+            logger.debug('Convert to XML: %s with definitions %s', val, types)
+
         converted_text, suc = convert_to_xml_single_values(val, types, logger=logger, float_format=float_format)
         all_success = all_success and suc
 
@@ -270,6 +285,9 @@ def convert_to_xml_explicit(value: Any | Iterable[Any],
     if len(converted_list) == 1 and not list_return:
         ret_value = converted_list[0]  #type:ignore
 
+    if logger is not None:
+        logger.debug('Converted Value to XML: %s', ret_value)
+
     return ret_value, all_success
 
 
@@ -321,7 +339,7 @@ def convert_from_xml_single_values(xmlstring: str | list[str],
                 except MissingConstant as exc:
                     new_exc = MissingConstant(f'No value available for expression {exc}\n'
                                               'Please provide the value for this constant'
-                                              ' by using the read_constants function for example')
+                                              ' by using the get_constants function for example')
 
                     exceptions.append(new_exc)
                     continue
