@@ -15,10 +15,11 @@ general attribute conditions from simple XPath expressions
 """
 from __future__ import annotations
 
-from typing import Any, Iterable, cast
-try:
-    from typing import TypeAlias  #type: ignore[attr-defined]
-except ImportError:
+from typing import Any, Iterable
+import sys
+if sys.version_info >= (3, 10):
+    from typing import TypeAlias
+else:
     from typing_extensions import TypeAlias
 
 from lxml import etree
@@ -113,7 +114,7 @@ class XPathBuilder:
     }
 
     def __init__(self,
-                 simple_path: etree._xpath,
+                 simple_path: str | bytes | etree.XPath,
                  filters: dict[str, FilterType] | None = None,
                  compile_path: bool = False,
                  strict: bool = False,
@@ -125,7 +126,7 @@ class XPathBuilder:
         if isinstance(simple_path, str):
             self.components = simple_path.rstrip('/').split('/')
         elif isinstance(simple_path, etree.XPath):
-            self.components = simple_path.path.split('/')  #type: ignore
+            self.components = simple_path.path.split('/')
         else:
             raise TypeError(f'Wrong type for simple path. Expected str or etree.XPath. Got {type(simple_path)}')
 
@@ -181,7 +182,7 @@ class XPathBuilder:
                       tag: str,
                       condition: Any,
                       compound: bool = False,
-                      path: str = '.',
+                      path: str | tuple[str, ...] = '.',
                       process_path: bool = False) -> str:
         """
         Construct the predicate for the given tag and condition
@@ -206,7 +207,12 @@ class XPathBuilder:
 
         return self.process_condition(tag, operator, content, path, process_path=process_path)
 
-    def process_condition(self, tag: str, operator: str, content: Any, path: str, process_path: bool = False) -> str:
+    def process_condition(self,
+                          tag: str,
+                          operator: str,
+                          content: Any,
+                          path: str | tuple[str, ...],
+                          process_path: bool = False) -> str:
         """
         Process the condition for the given tag and condition
 
@@ -325,7 +331,7 @@ class XPathBuilder:
         return '/'.join(path_variable)
 
     @property
-    def path(self) -> etree._xpath:
+    def path(self) -> str | etree.XPath:
         """
         Property for constructing the complex Xpath
         """
@@ -352,8 +358,7 @@ class XPathBuilder:
             raise ValueError(f'Implicit string conversion for {self.__class__.__qualname__}.')
         path = self.path
         if isinstance(path, etree.XPath):
-            path = path.path  #type: ignore
-        path = cast(str, path)
+            path = path.path
 
         for name, value in sorted(self.path_variables.items(), key=lambda x: len(x[0]), reverse=True):
             path = path.replace(f'${name}', f'{value!r}')
